[evolution-data-server/gnome-3-6] Revert "Bug #683867 - Schedule actions with higher idle priority"



commit 20aefc8b9eaa1bb57c5d2d829343107e0684b471
Author: Matthew Barnes <mbarnes redhat com>
Date:   Fri Feb 8 07:00:43 2013 -0500

    Revert "Bug #683867 - Schedule actions with higher idle priority"
    
    This reverts commit b6f0db12e7b2505b08ac0683c1d0d28d4a050ef3.
    
    The commit contains not a single comment as to why these custom priority
    values are being used.  The rationale needs to be documented in the code,
    either at each call point or preferably at a centralized priority value
    definition.

 calendar/libecal/e-cal.c           |    2 +-
 camel/camel-folder.c               |    8 ++++----
 camel/camel-imapx-server.c         |    2 +-
 camel/camel-service.c              |    2 +-
 camel/camel-session.c              |    2 +-
 camel/camel-store.c                |   16 ++++++++--------
 camel/camel-subscribable.c         |    8 ++++----
 libedataserver/e-gdbus-templates.c |    2 +-
 8 files changed, 21 insertions(+), 21 deletions(-)
---
diff --git a/calendar/libecal/e-cal.c b/calendar/libecal/e-cal.c
index b956550..3c43bed 100644
--- a/calendar/libecal/e-cal.c
+++ b/calendar/libecal/e-cal.c
@@ -1151,7 +1151,7 @@ async_report_idle (ECal *ecal,
 	data->ecal = g_object_ref (ecal);
 	data->error = error;
 
-	g_idle_add_full (G_PRIORITY_DEFAULT, idle_async_error_reply_cb, data, NULL);
+	g_idle_add (idle_async_error_reply_cb, data);
 }
 
 /**
diff --git a/camel/camel-imapx-server.c b/camel/camel-imapx-server.c
index 2708f16..75b73f6 100644
--- a/camel/camel-imapx-server.c
+++ b/camel/camel-imapx-server.c
@@ -6284,7 +6284,7 @@ imapx_server_dispose (GObject *object)
 
 	if (server->parser_thread) {
 		if (server->parser_thread == g_thread_self ())
-			g_idle_add_full (G_PRIORITY_HIGH, &join_helper, server->parser_thread, NULL);
+			g_idle_add (&join_helper, server->parser_thread);
 		else
 			g_thread_join (server->parser_thread);
 		server->parser_thread = NULL;
diff --git a/camel/camel-service.c b/camel/camel-service.c
index 6fed559..316b688 100644
--- a/camel/camel-service.c
+++ b/camel/camel-service.c
@@ -409,7 +409,7 @@ service_queue_notify_connection_status (CamelService *service)
 	session = camel_service_get_session (service);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		service_notify_connection_status_cb,
 		g_object_ref (service),
 		(GDestroyNotify) g_object_unref);
diff --git a/camel/camel-session.c b/camel/camel-session.c
index ba65eb8..abcf34f 100644
--- a/camel/camel-session.c
+++ b/camel/camel-session.c
@@ -53,7 +53,7 @@
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), CAMEL_TYPE_SESSION, CamelSessionPrivate))
 
-#define JOB_PRIORITY G_PRIORITY_DEFAULT
+#define JOB_PRIORITY G_PRIORITY_LOW
 
 #define d(x)
 
diff --git a/libedataserver/e-gdbus-templates.c b/libedataserver/e-gdbus-templates.c
index 5d99703..ef3e476 100644
--- a/libedataserver/e-gdbus-templates.c
+++ b/libedataserver/e-gdbus-templates.c
@@ -1015,7 +1015,7 @@ e_gdbus_op_cancelled_cb (GCancellable *cancellable,
 
 	/* do this on idle, because this callback should be left
 	 * as soon as possible, with no sync calls being done */
-	op_data->cancel_idle_id = g_idle_add_full (G_PRIORITY_DEFAULT, e_gdbus_op_cancelled_idle_cb, cd, cancel_data_free);
+	op_data->cancel_idle_id = g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, e_gdbus_op_cancelled_idle_cb, cd, cancel_data_free);
 }
 
 static void


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/camel/camel-folder.c b/camel/camel-folder.c
index 9788c96..a262b02 100644
--- a/camel/camel-folder.c
+++ b/camel/camel-folder.c
@@ -2782,7 +2782,7 @@ camel_folder_search_free (CamelFolder *folder,
  * Marks @folder as deleted and performs any required cleanup.
  *
  * This also emits the #CamelFolder::deleted signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  **/
 void
 camel_folder_delete (CamelFolder *folder)
@@ -2823,7 +2823,7 @@ camel_folder_delete (CamelFolder *folder)
 	signal_data->folder = g_object_ref (folder);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		folder_emit_deleted_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -2836,7 +2836,7 @@ camel_folder_delete (CamelFolder *folder)
  * Marks @folder as renamed.
  *
  * This also emits the #CamelFolder::renamed signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * NOTE: This is an internal function used by camel stores, no locking
  * is performed on the folder.
@@ -2873,7 +2873,7 @@ camel_folder_rename (CamelFolder *folder,
 	signal_data->folder_name = old_name;  /* transfer ownership */
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		folder_emit_renamed_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -2782,7 +2782,7 @@ camel_folder_search_free (CamelFolder *folder,
  *
  * This also emits the #CamelFolder::deleted signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  **/
 void
@@ -2836,7 +2836,7 @@ camel_folder_delete (CamelFolder *folder)
  *
  * This also emits the #CamelFolder::renamed signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * NOTE: This is an internal function used by camel stores, no locking
diff --git a/camel/camel-store.c b/camel/camel-store.c
index e80a304..b74126f 100644
--- a/camel/camel-store.c
+++ b/camel/camel-store.c
@@ -1268,7 +1268,7 @@ camel_store_error_quark (void)
  * @folder_info: information about the created folder
  *
  * Emits the #CamelStore::folder-created signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -1291,7 +1291,7 @@ camel_store_folder_created (CamelStore *store,
 	signal_data->folder_info = camel_folder_info_clone (folder_info);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		store_emit_folder_created_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -1302,7 +1302,7 @@ camel_store_folder_created (CamelStore *store,
  * @folder_info: information about the deleted folder
  *
  * Emits the #CamelStore::folder-deleted signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -1325,7 +1325,7 @@ camel_store_folder_deleted (CamelStore *store,
 	signal_data->folder_info = camel_folder_info_clone (folder_info);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		store_emit_folder_deleted_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -1336,7 +1336,7 @@ camel_store_folder_deleted (CamelStore *store,
  * @folder: the #CamelFolder that was opened
  *
  * Emits the #CamelStore::folder-opened signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -1359,7 +1359,7 @@ camel_store_folder_opened (CamelStore *store,
 	signal_data->folder = g_object_ref (folder);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		store_emit_folder_opened_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -1371,7 +1371,7 @@ camel_store_folder_opened (CamelStore *store,
  * @folder_info: information about the renamed folder
  *
  * Emits the #CamelStore::folder-renamed signal from an idle source on
  * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -1397,7 +1397,7 @@ camel_store_folder_renamed (CamelStore *store,
 	signal_data->folder_name = g_strdup (old_name);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		store_emit_folder_renamed_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -1268,7 +1268,7 @@ camel_store_error_quark (void)
  *
  * Emits the #CamelStore::folder-created signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.
@@ -1302,7 +1302,7 @@ camel_store_folder_created (CamelStore *store,
  *
  * Emits the #CamelStore::folder-deleted signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.
@@ -1336,7 +1336,7 @@ camel_store_folder_deleted (CamelStore *store,
  *
  * Emits the #CamelStore::folder-opened signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.
@@ -1371,7 +1371,7 @@ camel_store_folder_opened (CamelStore *store,
  *
  * Emits the #CamelStore::folder-renamed signal from an idle source on
- * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.
diff --git a/camel/camel-subscribable.c b/camel/camel-subscribable.c
index b73395e..ceb18d0 100644
--- a/camel/camel-subscribable.c
+++ b/camel/camel-subscribable.c
@@ -611,7 +611,7 @@ camel_subscribable_unsubscribe_folder_finish (CamelSubscribable *subscribable,
  * @folder_info: information about the subscribed folder
  *
  * Emits the #CamelSubscribable::folder-subscribed signal from an idle source
  * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -636,7 +636,7 @@ camel_subscribable_folder_subscribed (CamelSubscribable *subscribable,
 	signal_data->folder_info = camel_folder_info_clone (folder_info);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		subscribable_emit_folder_subscribed_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -647,7 +647,7 @@ camel_subscribable_folder_subscribed (CamelSubscribable *subscribable,
  * @folder_info: information about the unsubscribed folder
  *
  * Emits the #CamelSubscribable::folder-unsubscribed signal from an idle source
  * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
  *
  * This function is only intended for Camel providers.
  *
@@ -672,7 +672,7 @@ camel_subscribable_folder_unsubscribed (CamelSubscribable *subscribable,
 	signal_data->folder_info = camel_folder_info_clone (folder_info);
 
 	camel_session_idle_add (
-		session, G_PRIORITY_DEFAULT,
+		session, G_PRIORITY_DEFAULT_IDLE,
 		subscribable_emit_folder_unsubscribed_cb,
 		signal_data, (GDestroyNotify) signal_data_free);
 }
@@ -611,7 +611,7 @@ camel_subscribable_unsubscribe_folder_finish (CamelSubscribable *subscribable,
  *
  * Emits the #CamelSubscribable::folder-subscribed signal from an idle source
- * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.
@@ -647,7 +647,7 @@ camel_subscribable_folder_subscribed (CamelSubscribable *subscribable,
  *
  * Emits the #CamelSubscribable::folder-unsubscribed signal from an idle source
- * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT.
+ * on the main loop.  The idle source's priority is #G_PRIORITY_DEFAULT_IDLE.
  *
  * This function is only intended for Camel providers.